"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const database_1 = require("./database");
const defaults_1 = require("./defaults");
const manager_1 = require("./manager");
const server_1 = require("./server");
exports.plugin = {
    pkg: require("../package.json"),
    defaults: defaults_1.defaults,
    alias: "webhooks",
    async register(container, options) {
        const logger = container.resolvePlugin("logger");
        if (!options.enabled) {
            logger.info("Webhooks are disabled :grey_exclamation:");
            return;
        }
        await database_1.database.setUp(options.database);
        await manager_1.webhookManager.setUp();
        if (options.server.enabled) {
            return server_1.startServer(options.server);
        }
        logger.info("Webhooks API server is disabled :grey_exclamation:");
    },
    async deregister(container, options) {
        if (options.server.enabled) {
            container.resolvePlugin("logger").info("Stopping Webhook API");
            return container.resolvePlugin("webhooks").stop();
        }
    },
};
//# sourceMappingURL=index.js.map