"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const crypto_1 = require("crypto");
const database_1 = require("../database");
const schema = __importStar(require("./schema"));
const utils = __importStar(require("./utils"));
/**
 * @type {Object}
 */
const index = {
    /**
     * @param  {Hapi.Request} request
     * @param  {Hapi.Toolkit} h
     * @return {Hapi.Response}
     */
    async handler(request, h) {
        const webhooks = await database_1.database.paginate(utils.paginate(request));
        return utils.toPagination(request, webhooks);
    },
};
exports.index = index;
/**
 * @type {Object}
 */
const store = {
    /**
     * @param  {Hapi.Request} request
     * @param  {Hapi.Toolkit} h
     * @return {Hapi.Response}
     */
    async handler(request, h) {
        const token = crypto_1.randomBytes(32).toString("hex");
        request.payload.token = token.substring(0, 32);
        const webhook = await database_1.database.create(request.payload);
        webhook.token = token;
        return h.response(utils.respondWithResource(request, webhook)).code(201);
    },
    options: {
        plugins: {
            pagination: {
                enabled: false,
            },
        },
        validate: schema.store,
    },
};
exports.store = store;
/**
 * @type {Object}
 */
const show = {
    /**
     * @param  {Hapi.Request} request
     * @param  {Hapi.Toolkit} h
     * @return {Hapi.Response}
     */
    async handler(request, h) {
        const webhook = await database_1.database.findById(request.params.id);
        delete webhook.token;
        return utils.respondWithResource(request, webhook);
    },
    options: {
        validate: schema.show,
    },
};
exports.show = show;
/**
 * @type {Object}
 */
const update = {
    /**
     * @param  {Hapi.Request} request
     * @param  {Hapi.Toolkit} h
     * @return {Hapi.Response}
     */
    async handler(request, h) {
        await database_1.database.update(request.params.id, request.payload);
        return h.response(null).code(204);
    },
    options: {
        validate: schema.update,
    },
};
exports.update = update;
/**
 * @type {Object}
 */
const destroy = {
    /**
     * @param  {Hapi.Request} request
     * @param  {Hapi.Toolkit} h
     * @return {Hapi.Response}
     */
    async handler(request, h) {
        await database_1.database.destroy(request.params.id);
        return h.response(null).code(204);
    },
    options: {
        validate: schema.destroy,
    },
};
exports.destroy = destroy;
//# sourceMappingURL=handler.js.map