"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_http_utils_1 = require("@arkecosystem/core-http-utils");
const routes_1 = require("./routes");
async function startServer(config) {
    const server = await core_http_utils_1.createServer({
        host: config.host,
        port: config.port,
        routes: {
            cors: true,
            validate: {
                async failAction(request, h, err) {
                    throw err;
                },
            },
        },
    });
    await server.register({
        plugin: core_http_utils_1.plugins.whitelist,
        options: {
            whitelist: config.whitelist,
            name: "Webhook API",
        },
    });
    await server.register({
        plugin: require("hapi-pagination"),
        options: {
            meta: {
                baseUri: "",
            },
            query: {
                limit: {
                    default: config.pagination.limit,
                },
            },
            results: {
                name: "data",
            },
            routes: {
                include: config.pagination.include,
                exclude: ["*"],
            },
        },
    });
    await server.register({
        plugin: routes_1.registerRoutes,
        routes: { prefix: "/api" },
        options: config,
    });
    return core_http_utils_1.mountServer("Webhook API", server);
}
exports.startServer = startServer;
//# sourceMappingURL=index.js.map