"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const boom_1 = __importDefault(require("boom"));
const transformer_1 = require("./transformer");
/**
 * Transform the given data into a resource.
 * @param  {Hapi.Request} request
 * @param  {Object} data
 * @return {Object}
 */
const transformResource = (request, data) => transformer_1.transform(data);
exports.transformResource = transformResource;
/**
 * Transform the given data into a collection.
 * @param  {Hapi.Request} request
 * @param  {Object} data
 * @return {Array}
 */
const transformCollection = (request, data) => data.map(d => transformResource(request, d));
exports.transformCollection = transformCollection;
/**
 * Create a pagination object for the request.
 * @param  {Hapi.Request} request
 * @return {Object}
 */
const paginate = request => ({
    offset: (request.query.page - 1) * request.query.limit,
    limit: request.query.limit,
});
exports.paginate = paginate;
/**
 * Respond with a resource.
 * @param  {Hapi.Request} request
 * @param  {Object} data
 * @return {Hapi.Response}
 */
const respondWithResource = (request, data) => (data ? { data: transformResource(request, data) } : boom_1.default.notFound());
exports.respondWithResource = respondWithResource;
/**
 * Respond with a collection.
 * @param  {Hapi.Request} request
 * @param  {Object} data
 * @return {Object}
 */
const respondWithCollection = (request, data) => ({
    data: transformCollection(request, data),
});
exports.respondWithCollection = respondWithCollection;
/**
 * Alias of "transformResource".
 * @param  {Hapi.Request} request
 * @param  {Object} data
 * @return {Hapi.Response}
 */
const toResource = (request, data) => transformResource(request, data);
exports.toResource = toResource;
/**
 * Alias of "transformCollection".
 * @param  {Hapi.Request} request
 * @param  {Object} data
 * @return {Hapi.Response}
 */
const toCollection = (request, data) => transformCollection(request, data);
exports.toCollection = toCollection;
/**
 * Transform the given data into a pagination.
 * @param  {Hapi.Request} request
 * @param  {Object} data
 * @return {Hapi.Response}
 */
const toPagination = (request, data) => ({
    results: transformCollection(request, data.rows),
    totalCount: data.count,
});
exports.toPagination = toPagination;
//# sourceMappingURL=utils.js.map